"""This is “nester.py" module, and it provides one function called print_lol() which prints
lists that may or may not include nested lists."""

def print_tableau(liste,indent=False,level=0,fh=sys.stdout):
	for each_item in liste:
		if isinstance(each_item,list):
			print_tableau(each_item,indent,level+1,fh)
		else:
			if indent:
				for tab_stop in range(level):
					print("\t",end='',file=fh)
			print(each_item,file=fh)
